DateFieldFormatter class abstract

Date input formatter.

Inheritance
Implementers

Constructors

DateFieldFormatter(String separator)

Properties

firstSeparatorIndex → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondSeparatorIndex → int
no setter

Methods

completeDigits(int number, {required int digits}) → String
Complete number digits.
format(String dateWithoutSeparator) → String
Format input.
formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited