TextStyles class

Constructors

TextStyles({TextStyle? active, TextStyle? error, TextStyle? hint, TextStyle? text})

Properties

active → TextStyle
no setter
error → TextStyle
no setter
hashCode → int
The hash code for this object.
no setterinherited
hint → TextStyle
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → TextStyle
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited